@@ -1,6 +1,6 @@
-"""From http://stackoverflow.com/a/12260597/400691"""
 import sys
 
+import django
 from django.conf import settings
 
 
@@ -13,12 +13,20 @@ settings.configure(
     INSTALLED_APPS=(
         'orderable.tests',
     ),
+    MIDDLEWARE_CLASSES=[],
 )
+
+
+if django.VERSION >= (1, 7):
+    django.setup()
+
+
 try:
     from django.test.runner import DiscoverRunner
 except ImportError:
     from discover_runner.runner import DiscoverRunner
 
+
 test_runner = DiscoverRunner(verbosity=1)
 failures = test_runner.run_tests(['orderable'])
 if failures:
